# Heterozygosity, Inbreeding, RoH

Hetero, Inbreeding, RoH

```bash

cd Hetero_Inbreed_RoH

cp SPI_BJO_ROS_NoRelate_NU_Snps.Autosomes.withnonvariant.filtered3.vcf.gz .

module purge
module load VCFtools/0.1.16-intel-2018b-Perl-5.28.0
module load BCFtools/1.9-intel-2018b

bcftools index SPI_BJO_ROS_NoRelate_NU_Snps.Autosomes.withnonvariant.filtered3.vcf.gz
bcftools index -n SPI_BJO_ROS_NoRelate_NU_Snps.Autosomes.withnonvariant.filtered3.vcf.gz

# generate all the sample names
bcftools query -l SPI_BJO_ROS_NoRelate_NU_Snps.Autosomes.withnonvariant.filtered3.vcf.gz > samples
# get the samples per population
grep "BJO" samples > bjornoya
grep "ROS" samples > rost
grep "SPI" samples > spitsbergen

# However, the population file also needs a column with the population denoted in it. So we can generate this with awk.
awk '{print $1"\tBJO"}' bjornoya > pop_file
awk '{print $1"\tROS"}' rost >> pop_file
awk '{print $1"\tSPI"}' spitsbergen >> pop_file

#Do hetero per population
bcftools view -S bjornoya -O z -o BJO_NoRelate_NU_Snps.Autosomes.withnonvariant.filtered3.vcf.gz SPI_BJO_ROS_NoRelate_NU_Snps.Autosomes.withnonvariant.filtered3.vcf.gz
bcftools view -S rost -O z -o ROS_NoRelate_NU_Snps.Autosomes.withnonvariant.filtered3.vcf.gz SPI_BJO_ROS_NoRelate_NU_Snps.Autosomes.withnonvariant.filtered3.vcf.gz
bcftools view -S spitsbergen -O z -o SPI_NoRelate_NU_Snps.Autosomes.withnonvariant.filtered3.vcf.gz SPI_BJO_ROS_NoRelate_NU_Snps.Autosomes.withnonvariant.filtered3.vcf.gz

for i in BJO ROS SPI;
do echo $i ;
vcftools --gzvcf ${i}_NoRelate_NU_Snps.Autosomes.withnonvariant.filtered3.vcf.gz --het --out ${i}_heterozygosity ;
done

#this gives heterozygosity/homozygosity + inbreeding

```

Het with simply counting

```bash

#use bcftools to count number of heterozygous sites and divide per total number of sites
#do this for every sample

module purge
module load VCFtools/0.1.16-intel-2018b-Perl-5.28.0
module load BCFtools/1.9-intel-2018b

touch Heterozygosity_manual.txt
cat samples | while read line ;
do echo ${line} ;
bcftools view -s ${line} -O z -o ${line}_NoRelate_NU_Snps.Autosomes.withnonvariant.filtered3.vcf.gz SPI_BJO_ROS_NoRelate_NU_Snps.Autosomes.withnonvariant.filtered3.vcf.gz ;
Hetero=$(zcat ${line}_NoRelate_NU_Snps.Autosomes.withnonvariant.filtered3.vcf.gz | grep -v "#" | grep "0/1" | wc -l)
Total=$(zcat ${line}_NoRelate_NU_Snps.Autosomes.withnonvariant.filtered3.vcf.gz | grep -v "#" | wc -l)
echo -e "${line}\t${Hetero}\t${Total}" >> Heterozygosity_manual.txt
done


```
